@@ -77,6 +77,10 @@ BEGIN {
                     );
 }
 
+sub DESTROY {
+    # This sub will be called on object destruction
+} # End of sub DESTROY
+
 #===============================================================================
 #=========== Constants and globals                                          ====
 #===============================================================================
